# Accident Investigation Board Denmark and Danish Maritime Accident Investigation Board feed generator
# Required arguments:
#   $title: Channel title
#   $description: Channel description
#   $link: Channel link
# Expects pup JSON output holding <div class="item"> tags, outputs xmltodict-compatible JSON
# WARNING: Dates are locale-sensitive; the RSS feed might not generate correctly with another locale.
import "./helpers" as helpers;

{
    "rss": {
        "@version": "2.0",
        "@xmlns": {
            "media": "http://search.yahoo.com/mrss/"
        },
        "channel": {
            "title": $title,
            "description": $description,
            "link": $link,
            "language": "en-DK",
            "pubDate": (now | strftime("%a, %d %b %Y %T %z")),
            "docs": "https://www.rssboard.org/rss-specification",
            "ttl": 1440,
            "generator": "ITSB",
            "item": [
                .[]
                | . as $item
                | {
                    "title": .children[-1].children[-4].children[0].text,
                    "description": .children[-1].children[-1].text,
                    "link": (.["data-url"] | helpers::urlresolve($link)),
                    "guid": (.["data-url"] | helpers::urlresolve($link)),
                    "pubDate": (
                        .children[-1].children[-3].text
                        | if startswith("Published ") then .[-10:] else . end
                        | strptime("%d-%m-%Y")
                        | mktime
                        | strftime("%a, %d %b %Y %T %z")
                    ),
                    "category": [
                        .children[-1].children[-2].children[].children[0].text | {
                            "@domain": $link,
                            "#text": .
                        }
                    ]
                }
                # Optional MediaRSS thumbnail
                | if $item.children[0].class == "media" then
                    .["http://search.yahoo.com/mrss/:thumbnail"] = {
                        "@url": ($item.children[0].children[0].children[-1].src | helpers::urlresolve($link))
                    }
                else . end
            ]
        }
    }
}
